package tk.eclipse.plugin.jseditor.editors.additional;

import java.util.HashMap;
import java.util.Map;

import tk.eclipse.plugin.jseditor.editors.JavaScriptAssistProcessor;
import tk.eclipse.plugin.jseditor.editors.JavaScriptAssistProcessor.AssistInfo;

/**
 * <code>IAdditionalJavaScriptCompleter</code> implementation for <strong>prototype.js</strong>.
 * 
 * @author Naoki Takezoe
 */
public class PrototypeCompleter implements IAdditionalJavaScriptCompleter {
	
	private AssistInfo createAssistInfo(int type, String displayString, String replaceString){
		return new AssistInfo(type, displayString + " - prototype.js", replaceString);
	}
	
	public AssistInfo[] getGlobalAssistInformations() {
		return new AssistInfo[]{
				createAssistInfo(JavaScriptAssistProcessor.OBJECT, "Ajax", "Ajax"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "$(element)", "$()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "$$(cssRule...)", "$$()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "$F(element)", "$F()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "$A(iterable)", "$A()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "$H([obj])", "$H()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "$R(start, end[, exclusive = false])", "$R()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "$w(String)", "$w()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "Try.these(Function...)", "Try.these()")
		};
	}
	public Map<String, AssistInfo[]> getClassAssistInformations(){
		Map<String, AssistInfo[]> map = new HashMap<String, AssistInfo[]>();
		map.put("Object", new AssistInfo[]{
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "extend(dest, src)", "extend()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "hide()", "hide()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "scrollTo()", "scrollTo()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "addClassName()", "addClassName()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "bind()", "bind()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "bindAsEventListener()", "bindAsEventListener()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "toJSON()", "toJSON()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "isArray(obj)", "isArray()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "isHash(obj)", "isHash()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "isElement(obj)", "isElement()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "isFunction(obj)", "isFunction()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "isNumber(obj)", "isNumber()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "isString(obj)", "isString()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "isUndefined(obj)", "isUndefined()")
		});
		map.put("Class", new AssistInfo[]{
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "create([superclass][, methods...])", "create()")
		});
		map.put("Event", new AssistInfo[]{
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "observe(element, eventName, handler[, useCapture = false])", "observe()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "stopObserving(element, eventName, handler[, useCapture = false])", "stopObserving()")
		});
		map.put("Ajax", new AssistInfo[]{
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "Request(url[, options])", "Request()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "Updater(container, url[, options])", "Updater()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "PeriodicalUpdater(container, url[, options])", "PeriodicalUpdater()"),
				createAssistInfo(JavaScriptAssistProcessor.VARIABLE, "Responders", "Responders"),
		});
		map.put("Responders", new AssistInfo[]{
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "register(responder)", "register()"),
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "unregister(responder)", "unregister()")
		});
		map.put("document", new AssistInfo[]{
				createAssistInfo(JavaScriptAssistProcessor.FUNCTION, "getElementsByClassName(className[, element])", "getElementsByClassName()")
		});
		
		return map;
	}

	public boolean isLibraryScriptFile(String fileName) {
		return fileName.startsWith("prototype") && fileName.endsWith(".js");
	}
	
}
